@@ -73,7 +73,7 @@ cDialog_About::~cDialog_About()
 // Constructor
 cMDialog_PdftkError::cMDialog_PdftkError( Gtk::Window& ref_window )
 :
-	Gtk::MessageDialog( ref_window , _("PDFTK returned error!") , false ,  Gtk::MESSAGE_ERROR , Gtk::BUTTONS_CLOSE , false )
+	Gtk::MessageDialog( ref_window , _("The PDFtk returned") , false ,  Gtk::MESSAGE_ERROR , Gtk::BUTTONS_CLOSE , false )
 {
 }
 
@@ -91,7 +91,7 @@ cMDialog_PdftkError::~cMDialog_PdftkError()
 void
 cMDialog_PdftkError::popupMessage( const Glib::ustring& str_error_text , int error_code )
 {
-	std::cerr << std::endl << str_error_text << " - PDFTK returned: " << error_code << std::endl;
+//	std::cerr << std::endl << str_error_text << " - PDFTK returned: " << error_code << std::endl;
 
 	Glib::ustring str_secondary_text = str_error_text + + "\n" + _("Error code:") + " "
 		+ static_cast<Glib::ustring>( Pdfchain::convert_guint_to_string( static_cast<guint>( error_code ) ) );
