@@ -28,7 +28,7 @@ cFCDialog_AddFile::cFCDialog_AddFile(
 	Gtk::Window& ref_window ,
 	const Glib::ustring& str_title )
 :
-	Gtk::FileChooserDialog( ref_window , str_title )
+	Gtk::FileChooserDialog( ref_window , str_title , Gtk::FILE_CHOOSER_ACTION_OPEN )
 {
 	set_select_multiple( true );
 	
@@ -57,10 +57,20 @@ cFCDialog_AddFile::clear()
 }
 
 
+// Method (public, overwrite) : run
+int
+cFCDialog_AddFile::run()
+{
+	set_current_folder( get_current_folder() );
+	return Gtk::FileChooserDialog::run();
+}
+
+
 // Method (protected) : init
 void
 cFCDialog_AddFile::init()
 {
+	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );	
 	return;
 }
 
@@ -157,6 +167,15 @@ cFCDialog_SaveAs::clear()
 }
 
 
+// Method (public, overwrite) : run
+int
+cFCDialog_SaveAs::run()
+{
+	set_current_folder( get_current_folder() );
+	return Gtk::FileChooserDialog::run();
+}
+
+
 // Method (public) : get filename
 std::string
 cFCDialog_SaveAs::get_filename()
@@ -300,10 +319,11 @@ cFCDialog_SelectFolder::cFCDialog_SelectFolder(
 	Gtk::FileChooserDialog( ref_window , str_title , Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER )
 {
 	add_button( Gtk::Stock::CANCEL    , Gtk::RESPONSE_CANCEL );
-	add_button( Gtk::Stock::DIRECTORY , Gtk::RESPONSE_OK );
+//	add_button( Gtk::Stock::DIRECTORY , Gtk::RESPONSE_OK );	// Gtk::Stock::DIRECTORY doesn't work right
+	add_button( Gtk::Stock::OPEN      , Gtk::RESPONSE_OK );
 
-	add_filter( Glib::RefPtr<cFFilter_Pdf>( new cFFilter_Pdf() ) );
 	add_filter( Glib::RefPtr<cFFilter_Any>( new cFFilter_Any() ) );
+	add_filter( Glib::RefPtr<cFFilter_Pdf>( new cFFilter_Pdf() ) );
 	
 	set_select_multiple( false );
 	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );
@@ -318,6 +338,32 @@ cFCDialog_SelectFolder::~cFCDialog_SelectFolder()
 #endif
 }
 
+// Method (public) : clear
+void
+cFCDialog_SelectFolder::clear()
+{
+	init();
+	return;
+}
+
+
+// Method (public, overwrite) : run
+int
+cFCDialog_SelectFolder::run()
+{
+	set_current_folder( get_current_folder() );
+	return Gtk::FileChooserDialog::run();
+}
+
+
+// Method (protected) : init
+void
+cFCDialog_SelectFolder::init()
+{
+	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );	
+	return;
+}
+
 
 
 /*** File Chooser Button ******************************************************/
@@ -334,7 +380,7 @@ cFCButton_Pdf::cFCButton_Pdf( Gtk::Window& ref_window , const Glib::ustring& str
 	add_filter( Glib::RefPtr<cFFilter_Pdf>( new cFFilter_Pdf() ) );
 	add_filter( Glib::RefPtr<cFFilter_Any>( new cFFilter_Any() ) );
 	
-	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );
+	clear();
 }
 
 
@@ -347,6 +393,16 @@ cFCButton_Pdf::~cFCButton_Pdf()
 }
 
 
+// Method (public) : clear
+void
+cFCButton_Pdf::clear()
+{
+	unselect_all();
+	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );	
+	return;
+}
+
+
 
 /*** File Chooser Button - FDF ************************************************/
 
@@ -359,7 +415,7 @@ cFCButton_Fdf::cFCButton_Fdf( Gtk::Window& ref_window , const Glib::ustring& str
 	add_filter( Glib::RefPtr<cFFilter_Text>( new cFFilter_Text() ) );
 	add_filter( Glib::RefPtr<cFFilter_Any>(  new cFFilter_Any()  ) );
 	
-	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );
+	clear();
 }
 
 
@@ -372,6 +428,16 @@ cFCButton_Fdf::~cFCButton_Fdf()
 }
 
 
+// Method (public) : clear
+void
+cFCButton_Fdf::clear()
+{
+	unselect_all();
+	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );	
+	return;
+}
+
+
 
 /*** File Chooser Button - Dump ***********************************************/
 
@@ -384,7 +450,7 @@ cFCButton_Dump::cFCButton_Dump( Gtk::Window& ref_window , const Glib::ustring& s
 	add_filter( Glib::RefPtr<cFFilter_Text>( new cFFilter_Text() ) );
 	add_filter( Glib::RefPtr<cFFilter_Any>(  new cFFilter_Any()  ) );
 	
-	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );
+	clear();
 }
 
 
@@ -396,3 +462,13 @@ cFCButton_Dump::~cFCButton_Dump()
 #endif
 }
 
+
+// Method (public) : clear
+void
+cFCButton_Dump::clear()
+{
+	unselect_all();
+	set_current_folder( Glib::get_user_special_dir( G_USER_DIRECTORY_DOCUMENTS ) );	
+	return;
+}
+
