@@ -52,6 +52,7 @@ void
 cLStore_Cat::clear()
 {
 	Gtk::ListStore::clear();
+	mFCDialog.clear();
 	countFiles();
 	return;
 }
@@ -60,7 +61,7 @@ cLStore_Cat::clear()
 // Method (public) : add new rows (files)
 void
 cLStore_Cat::addRows(
-	Glib::RefPtr<Gtk::TreeSelection> ref_tree_selections )
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
 {
 	switch ( mFCDialog.run() ) {
 		case Gtk::RESPONSE_OK: {
@@ -122,7 +123,7 @@ cLStore_Cat::addRows(
 // Method (public) : remove selected rows
 void
 cLStore_Cat::removeRows(
-	Glib::RefPtr<Gtk::TreeSelection> ref_tree_selections )
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
 {
 	std::vector<Gtk::TreeModel::Path>
 		list_selections = ref_tree_selections->get_selected_rows();
@@ -158,7 +159,7 @@ cLStore_Cat::removeRows(
 // Method (public) : copy selected Rows
 void
 cLStore_Cat::copyRows(
-	Glib::RefPtr<Gtk::TreeSelection> ref_tree_selections )
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
 {
 	std::vector<Gtk::TreeModel::Path>
 		list_selections = ref_tree_selections->get_selected_rows();
@@ -183,8 +184,8 @@ cLStore_Cat::copyRows(
 
 // Method (public) : move selected rows up
 void
-cLStore_Cat::moveRowsUp(
-	Glib::RefPtr<Gtk::TreeSelection> ref_tree_selections )
+cLStore_Cat::moveRows_Up(
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
 {
 	std::vector<Gtk::TreeModel::Path>
 		list_selections = ref_tree_selections->get_selected_rows();
@@ -213,8 +214,8 @@ cLStore_Cat::moveRowsUp(
 
 // Method (public) : move selected rows down
 void
-cLStore_Cat::moveRowsDown(
-	Glib::RefPtr<Gtk::TreeSelection> ref_tree_selections )
+cLStore_Cat::moveRows_Down(
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
 {
 	std::vector<Gtk::TreeModel::Path>
 		list_selections = ref_tree_selections->get_selected_rows();
@@ -241,6 +242,47 @@ cLStore_Cat::moveRowsDown(
 }
 
 
+// Method (public) : move selected rows up to top
+void
+cLStore_Cat::moveRows_ToTop(
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
+{
+	std::vector<Gtk::TreeModel::Path>
+		list_selections = ref_tree_selections->get_selected_rows();
+
+	if ( list_selections.size() ) {
+
+		// Move every row till first selected row is the first row at the ListStore
+		while ( children().begin() !=  get_iter( list_selections.front() ) ) {
+			moveRows_Up( ref_tree_selections );
+			list_selections = ref_tree_selections->get_selected_rows();
+		}
+	}
+
+	return;
+}
+
+
+// Method (public) : move selected rows down to bottom
+void
+cLStore_Cat::moveRows_ToBottom(
+	Glib::RefPtr<Gtk::TreeView::Selection> ref_tree_selections )
+{
+	std::vector<Gtk::TreeModel::Path>
+		list_selections = ref_tree_selections->get_selected_rows();
+
+	if ( list_selections.size() ) {
+
+		// Move every row till first selected row is the first row at the ListStore
+		while ( --children().end() !=  get_iter( list_selections.back() ) ) {
+			moveRows_Down( ref_tree_selections );
+			list_selections = ref_tree_selections->get_selected_rows();
+		}
+	}
+
+	return;
+}
+
 
 // Method (protected) : indicate File ID
 // Idicates every document at an active row at the store with an unique file id
@@ -805,7 +847,7 @@ cLStore_Cat::copyRow(
 // Method (public) : toggle Add
 void
 cLStore_Cat::toggleAdd(
-	const Gtk::TreePath& treepath )
+	const Gtk::TreeModel::Path& treepath )
 {
 	Gtk::TreeModel::iterator
 		iter = get_iter( treepath );
@@ -820,7 +862,7 @@ cLStore_Cat::toggleAdd(
 // Method (public) : edit Pages
 void
 cLStore_Cat::editPages(
-	const Gtk::TreePath& treepath ,
+	const Gtk::TreeModel::Path& treepath ,
 	const Glib::ustring& str_pages )
 {
 	Gtk::TreeModel::iterator
@@ -848,7 +890,7 @@ cLStore_Cat::editPages(
 // Method (public) : change EvenOdd
 void
 cLStore_Cat::changeEvenOdd(
-	const Gtk::TreePath& treepath ,
+	const Gtk::TreeModel::Path& treepath ,
 	const Glib::ustring& str_label ,
 	const std::string& str_command )
 {
@@ -862,7 +904,7 @@ cLStore_Cat::changeEvenOdd(
 // Method (public) : change Rotation
 void
 cLStore_Cat::changeRotation(
-	const Gtk::TreePath& treepath ,
+	const Gtk::TreeModel::Path& treepath ,
 	const Glib::ustring& str_label ,
 	const std::string& str_command )
 {
@@ -879,7 +921,7 @@ cLStore_Cat::changeRotation(
 // Method (public) : edit Password
 void
 cLStore_Cat::editPassword(
-	const Gtk::TreePath& treepath ,
+	const Gtk::TreeModel::Path& treepath ,
 	const Glib::ustring& str_password )
 {
 	Gtk::TreeModel::iterator
