@@ -28,6 +28,10 @@
 #include "window_main_tool.h"
 #include "window_main_permission.h"
 
+class cNotebook_Sections;
+class cHBox_Execute;
+class cWindow_Main;
+
 
 /*** Notebook : Sections ******************************************************/
 
@@ -37,33 +41,37 @@ cNotebook_Sections : public Gtk::Notebook
 	friend class cWindow_Main;
 	
 	public:
-
+	
+		// Constructor
 		         cNotebook_Sections( Gtk::Window& );
 		virtual ~cNotebook_Sections();
 		
+		// Methodes
 		void clear();
 		
 	protected:
-
-
-		Gtk::Label     mLabel_Cat,
-		               mLabel_Burst,
-		               mLabel_BgSt,
-		               mLabel_Attach,
-		               mLabel_Tool;
-
-		Gtk::Alignment mAlign_Cat,
-		               mAlign_Burst,
-		               mAlign_BgSt,
-		               mAlign_Attach,
-		               mAlign_Tool;
 	
-
+		// Derived Widgets (Sections)
 		cSection_Cat    mSection_Cat;
 		cSection_Burst  mSection_Burst;
 		cSection_BgSt   mSection_BgSt;
 		cSection_Attach mSection_Attach;
 		cSection_Tool   mSection_Tool;
+		
+		// Widgets
+		Gtk::Label
+			mLabel_Cat,
+			mLabel_Burst,
+			mLabel_BgSt,
+			mLabel_Attach,
+			mLabel_Tool;
+
+		Gtk::Alignment
+			mAlign_Cat,
+			mAlign_Burst,
+			mAlign_BgSt,
+			mAlign_Attach,
+			mAlign_Tool;
 };
 
 
@@ -76,15 +84,44 @@ cHBox_Execute : public Gtk::HBox
 	friend class cWindow_Main;
 	
 	public:
+	
+		// Constructor
 		         cHBox_Execute();
 		virtual ~cHBox_Execute();
 
 	protected:
 
-		Gtk::Statusbar mSBar_Main;
-		Gtk::Button    mButton_Execute,
-		               mButton_Clear,
-		               mButton_About;
+		// Widgets
+		Gtk::Statusbar
+			mSBar_Main;
+
+		Gtk::Button
+			mButton_Execute;
+
+		Gtk::ToggleButton
+			mTButton_Permission;
+#ifndef PDFCHAIN_GTKMM_OLD
+		Gtk::MenuButton
+			mMButton;
+
+		Gtk::Menu
+			mMenu;
+
+		Gtk::ImageMenuItem
+			mIMItem_About ,
+			mIMItem_Clear;
+
+		Gtk::SeparatorMenuItem
+			mMISeparator_A;
+#else
+		Gtk::Image
+			mImg_About ,
+			mImg_Clear;
+
+		Gtk::Button
+			mButton_About ,
+			mButton_Clear;
+#endif
 };
 
 
@@ -95,33 +132,55 @@ class
 cWindow_Main : public Gtk::Window
 {
 	public:
+	
+		// Constructor
 		         cWindow_Main();
 		virtual ~cWindow_Main();
 		
+		// Methodes
 		void clear();
 		
 	protected:
 	
+		// Methodes
 		void init();
 
-		void confirmErrorCode( int );
+		void confirmErrorCode( const int );
 
-		void onNotebook_Sections_switch_page( Widget* , guint );
-		void onButton_About_clicked();
-		void onButton_Clear_clicked();
-		void onButton_Execute_clicked();
+		// Signal Handler
+		inline void onNotebook_Sections_switch_page( const Widget* , const guint );
+		inline void onIMItem_About_activated();
+		inline void onIMItem_Clear_activated();
+		inline void onTButton_Permission_toggled();
+		inline void onButton_Execute_clicked();
 
+		// Signal Connector
 		sigc::connection mConnection_NotebookSections_signal_switch_page;
 
-		Gtk::VBox            mVBox_Main;
-		Gtk::Alignment       mAlign_Sections,
-		                     mAlign_Permission,
-		                     mAlign_Execute;
-		cNotebook_Sections   mNotebook_Sections;
-		cExpander_Permission mExpander_Permission;
-		cHBox_Execute        mHBox_Execute;
-		cMDialog_PdftkError  mMDialog_PdftkError;
-		cDialog_About        mDialog_About;
+		// Derived Widgets
+		cNotebook_Sections
+			mNotebook_Sections;
+			
+		cSection_Permission
+			mSection_Permission;
+			
+		cHBox_Execute
+			mHBox_Execute;
+			
+		cMDialog_PdftkError
+			mMDialog_PdftkError;
+			
+		cDialog_About
+			mDialog_About;
+
+		// Widgets
+		Gtk::VBox
+			mVBox_Main;
+			
+		Gtk::Alignment
+			mAlign_Sections,
+			mAlign_Permission,
+			mAlign_Execute;
 };
 
 
