@@ -26,55 +26,58 @@
 /*** Section : Background / Stamp *********************************************/
 
 class
-cSection_BgSt : public Gtk::Table
+cSection_BgSt : public Gtk::VBox
 {
 	public:
+	
+		// Constructor
 		         cSection_BgSt( Gtk::Window& );
 		virtual ~cSection_BgSt();
 
+		// Methodes
 		void clear();
 		std::string createCommand();
 		
 	private:
 
-//		guint vPageNumbers_SourceFile,
-		guint vPageNumbers_BgStFile;
-
-		Gtk::HBox             mHBox_Insert;
-		Gtk::Label            mLabel_SourceFile,
-		                      mLabel_BgStFile,
-		                      mLabel_Insert,
-		                      mLabel_Multiple;
-		cFCButton_Pdf         mFCButton_SourceFile,
-		                      mFCButton_BgStFile;
-		Gtk::RadioButton      mRButton_Background,
-		                      mRButton_Stamp;
-		Gtk::RadioButtonGroup mRBGroup_BgSt;
-		Gtk::Switch           mSwitch_Multiple;
-//		cFCDialog_SaveAs      mFCDialog_SaveAs;
-		cFCDialog_SaveAs_Pdf  mFCDialog_SaveAs;
-
-
+		// Methodes 
 		void init();
 
-//		void onFCButton_SourceFile_file_set() {
-//			vPageNumbers_SourceFile = Pdfchain::count_page_numbers(
-//				mFCButton_SourceFile.get_filename() );
-//			return;
-//		}
+		// Signal Handler
+		inline void onFCButton_BgStFile_file_set();
 
-		void onFCButton_BgStFile_file_set()
-		{
-			vPageNumbers_BgStFile =
-				Pdfchain::count_page_numbers( mFCButton_BgStFile.get_filename() );
+		// Widgets
+		Gtk::HBox
+			mHBox_SourceFile ,
+			mHBox_BgSt;
 
-			if ( 1 < vPageNumbers_BgStFile )
-				mSwitch_Multiple.set_active( true );
-			else
-				mSwitch_Multiple.set_active( false );
-				
-			return;
-		}
+		Gtk::Label
+			mLabel_SourceFile ,
+			mLabel_BgStFile;
+
+		Gtk::Frame
+			mFrame_BgSt;
+
+		Gtk::Table
+			mTable_BgSt;
+
+		Gtk::CheckButton
+			mCButton_Multiple;
+
+		Gtk::RadioButton			// Declaration of Gtk::RadioButton before Gtk::RadioButtonGroup!!!
+			mRButton_Background ,
+			mRButton_Stamp;
+
+		Gtk::RadioButtonGroup		// Declaration of Gtk::RadioButtonGroup behind Gtk::RadioButton!!!
+			mRBGroup_BgSt;
+
+		// Derived Widgets
+		cFCButton_Pdf
+			mFCButton_SourceFile ,
+			mFCButton_BgStFile;
+
+		cFCDialog_SaveAs_Pdf
+			mFCDialog_SaveAs;
 };
 
 
