@@ -46,61 +46,103 @@ cCBox_CountingBase::~cCBox_CountingBase()
 // Constructor
 cSection_Burst::cSection_Burst( Gtk::Window& ref_window )
 :
-	Gtk::Table( 6 , 2 , false ),	// y_rows , x_columns , homogenous )
+	Gtk::VBox( false , Pdfchain::SPACING ) ,	// homogeneous , spacing
 
-	mFCButton_SourceFile(   ref_window , _("Burst - Select source PDF file ...") ),	// parent_window , title
-	mFCDialog_SelectFolder( ref_window , _("Burst - Select output folder ...") ),
+	mHBox_SourceFile( false , Pdfchain::SPACING ) ,	// homogeneous , spacing
+	mHBox_Prefix(     false , Pdfchain::SPACING ) ,
+	mHBox_Digits(     false , Pdfchain::SPACING ) ,
 
-	mLabel_SourceFile( _("Source file:") , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),	// label , xalign , yalign , mnemonic
-	mLabel_Prefix(     _("Prefix:")      , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
-	mLabel_Base(       _("Base:")        , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
-	mLabel_Digits(     _("Digits:")      , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
-	mLabel_Suffix(     _("Suffix:")      , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
-	mLabel_Extension(  _("Extension:")   , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
+	mVBox_Pattern(    false , Pdfchain::SPACING ) ,
+
+	mLabel_Pattern(    _("Output PDF pattern") , Gtk::ALIGN_CENTER , Gtk::ALIGN_CENTER , false ) ,
+	mLabel_Extended(   _("Extended options")   , Gtk::ALIGN_CENTER , Gtk::ALIGN_CENTER , false ) ,
+	mLabel_SourceFile( _("Document:") , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),	// label , xalign , yalign , mnemonic
+	mLabel_Prefix(     _("Prefix:")   , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
+	mLabel_Base(       _("Base:")     , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
+	mLabel_Digits(     _("Digits:")   , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
+	mLabel_Suffix(     _("Suffix:")   , Gtk::ALIGN_END , Gtk::ALIGN_CENTER , false ),
 
 	mRBGroup_CounterDigits( mRButton_Auto.get_group() ),
-	mRButton_Auto(		mRBGroup_CounterDigits , _("Auto")		, false ),	// group , label , mnemonic
-	mRButton_Manual(	mRBGroup_CounterDigits , _("Manual:")	, false ),
+	mRButton_Auto(   mRBGroup_CounterDigits , _("Auto")	   , false ),	// group , label , mnemonic
+	mRButton_Manual( mRBGroup_CounterDigits , _("Manual:") , false ),
 
-	rAdjust_Digits( Gtk::Adjustment::create( 0.0 , 0.0 , Pdfchain::Burst::ADJUST_UPPER_DIGITS , 1.0 , 1.0 , 0.0 ) ),	// value , lower , upper , step_inc , page_inc , page_size
+	rAdjust_Digits( Gtk::Adjustment::create(
+		0.0 , 0.0 , Pdfchain::Burst::ADJUST_UPPER_DIGITS , 1.0 , 1.0 , 0.0 ) ),	// value , lower , upper , step_inc , page_inc , page_size
 	mSButton_Digits( rAdjust_Digits ),
 
+	mCButton_Extension( _("Extension") , false ) ,	// label , mnemonic
+
 	sPrefix( _("Page") ),
 	sSuffix( _("") ),
 	vPageNumbers( 0 ),
-	vDigits_Oct( 0 ),
-	vDigits_Dec( 0 ),
-	vDigits_Hex( 0 )
+
+	mFCButton_SourceFile(   ref_window , _("Burst - Select source PDF file ...") ) ,	// parent_window , title
+	mFCDialog_SelectFolder( ref_window , _("Burst - Select output folder ...") ) ,
+
+	rSGroup_LabelPattern( Gtk::SizeGroup::create( Gtk::SIZE_GROUP_HORIZONTAL ) )
 {
+	// Assemble Widgets
+	mLabel_Pattern.set_tooltip_text(     _("Prepare the pattern for the output PDF file names") );
+	mLabel_Extended.set_tooltip_text(    _("Extended options to format the pattern") );
+	mLabel_SourceFile.set_tooltip_text(  _("The source PDF file. "
+		"Every single page of this document will be saved in a seperate PDF file") );
+	mLabel_Prefix.set_tooltip_text(	     _("Prefix part of the file name pattern") );
+	mLabel_Base.set_tooltip_text(        _("Numbering base for the file counter part") );
+	mLabel_Digits.set_tooltip_text(      _("Number of digits for the file counter part") );  
+	mLabel_Suffix.set_tooltip_text(      _("Suffix part of the file name pattern") );  
+	mCButton_Extension.set_tooltip_text( _("Appends the extension \".pdf\" part") );
+	mRButton_Auto.set_tooltip_text(      _("Calculate number of counter digits automatically") );
+	mRButton_Manual.set_tooltip_text(    _("Define number of counter digits manually") );
+
+	mFrame_Pattern.set_label_widget( mLabel_Pattern );
+	mExpander_Extended.set_label_widget( mLabel_Extended );
+
 	mEntry_Prefix.set_icon_from_stock(	Gtk::Stock::CLEAR , Gtk::ENTRY_ICON_SECONDARY );
 	mEntry_Suffix.set_icon_from_stock(	Gtk::Stock::CLEAR , Gtk::ENTRY_ICON_SECONDARY );
 
-	mHBox_Digits.set_spacing( Pdfchain::SPACING );
-	mHBox_Digits.pack_start( mRButton_Auto   , false , false , 0 );	// widget , expand , fill , padding
+	mFCButton_SourceFile.set_halign( Gtk::ALIGN_START );
+	mEntry_Prefix.set_halign(        Gtk::ALIGN_START );
+	mCBox_CountingBase.set_halign(   Gtk::ALIGN_START );
+	mHBox_Digits.set_halign(         Gtk::ALIGN_START );
+	mEntry_Suffix.set_halign(        Gtk::ALIGN_START );
+
+	rSGroup_LabelPattern->add_widget( mLabel_Prefix );
+	rSGroup_LabelPattern->add_widget( mLabel_Suffix );
+	rSGroup_LabelPattern->add_widget( mLabel_Digits );
+	rSGroup_LabelPattern->add_widget( mLabel_Base );
+
+	mHBox_SourceFile.pack_start( mLabel_SourceFile    , false , false , 0 );	// widget , expand , fill , padding
+	mHBox_SourceFile.pack_start( mFCButton_SourceFile , false , true  , 0 );
+
+	mHBox_Prefix.pack_start( mLabel_Prefix , false , false , 0 );
+	mHBox_Prefix.pack_start( mEntry_Prefix , false , true  , 0 );
+
+	mHBox_Digits.pack_start( mRButton_Auto   , false , false , 0 );
 	mHBox_Digits.pack_start( mRButton_Manual , false , false , 0 );
 	mHBox_Digits.pack_start( mSButton_Digits , false , false , 0 );
 
-	mFCButton_SourceFile.set_halign( Gtk::ALIGN_START );
-	mEntry_Prefix.set_halign( Gtk::ALIGN_START );
-	mCBox_CountingBase.set_halign( Gtk::ALIGN_START );
-	mHBox_Digits.set_halign( Gtk::ALIGN_START );
-	mEntry_Suffix.set_halign( Gtk::ALIGN_START );
-	mSwitch_Extension.set_halign( Gtk::ALIGN_START );
+	mTable_Extended.set_margin_top( Pdfchain::BORDER );
+	mTable_Extended.set_spacings( Pdfchain::SPACING );
+	mTable_Extended.attach( mLabel_Base         , 0 , 1 , 0 , 1 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mCBox_CountingBase  , 1 , 2 , 0 , 1 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mLabel_Digits       , 0 , 1 , 1 , 2 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mHBox_Digits        , 1 , 2 , 1 , 2 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mLabel_Suffix       , 0 , 1 , 2 , 3 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mEntry_Suffix       , 1 , 2 , 2 , 3 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mTable_Extended.attach( mCButton_Extension  , 1 , 2 , 3 , 4 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
 
-	set_spacings( Pdfchain::SPACING );
-	attach( mLabel_SourceFile    , 0 , 1 , 0 , 1 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 0 -> 1
-	attach( mFCButton_SourceFile , 1 , 2 , 0 , 1 , Gtk::FILL | Gtk::EXPAND , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
-	attach( mLabel_Prefix        , 0 , 1 , 1 , 2 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 1 -> 2
-	attach( mEntry_Prefix        , 1 , 2 , 1 , 2 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
-	attach( mLabel_Base          , 0 , 1 , 2 , 3 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 2 -> 3
-	attach( mCBox_CountingBase   , 1 , 2 , 2 , 3 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
-	attach( mLabel_Digits        , 0 , 1 , 3 , 4 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
-	attach( mHBox_Digits         , 1 , 2 , 3 , 4 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 3 -> 4
-	attach( mLabel_Suffix        , 0 , 1 , 4 , 5 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 4 -> 5
-	attach( mEntry_Suffix        , 1 , 2 , 4 , 5 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
-	attach( mLabel_Extension     , 0 , 1 , 5 , 6 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );	// row 5 -> 6
-	attach( mSwitch_Extension    , 1 , 2 , 5 , 6 , Gtk::FILL | Gtk::SHRINK , Gtk::FILL | Gtk::SHRINK , 0 , 0 );
+	mExpander_Extended.add( mTable_Extended );
 
+	mVBox_Pattern.set_border_width( Pdfchain::BORDER );
+	mVBox_Pattern.pack_start( mHBox_Prefix );
+	mVBox_Pattern.pack_start( mExpander_Extended );
+
+	mFrame_Pattern.add( mVBox_Pattern );
+
+	pack_start( mHBox_SourceFile , false , false , 0 );
+	pack_start( mFrame_Pattern   , false , false , 0 );
+
+	// Connect File Handler
 	mEntry_Prefix.signal_icon_press().connect( sigc::mem_fun(
 		*this , &cSection_Burst::onEntryIcon_Prefix_pressed ) );
 		
@@ -116,6 +158,7 @@ cSection_Burst::cSection_Burst( Gtk::Window& ref_window )
 	mFCButton_SourceFile.signal_file_set().connect( sigc::mem_fun(
 		*this , &cSection_Burst::onFCButton_SourceFile_file_set ) );
 	
+	// Init Object
 	init();
 }
 
@@ -135,10 +178,10 @@ cSection_Burst::clear()
 {
 	init();
 	
-//	vPageNumbers = 0;
-//	vDigits_Oct  = 0;
-//	vDigits_Dec  = 0;
-//	vDigits_Hex  = 0;
+	vPageNumbers = 0;
+	vDigits_Oct  = 0;
+	vDigits_Dec  = 0;
+	vDigits_Hex  = 0;
 	
 	return;
 }
@@ -195,7 +238,7 @@ cSection_Burst::createCommand()
 					str_bursttemplate += iter->get_value( pt_record->mTMColumn_Command );
 					str_bursttemplate += str_suffix;
 
-					if ( mSwitch_Extension.get_active() )
+					if ( mCButton_Extension.get_active() )
 						str_bursttemplate += Pdfchain::Cmd::EXTENSION;
 
 					str_command  = " " + Pdfchain::quote_path( str_sourcefile );
@@ -210,7 +253,7 @@ cSection_Burst::createCommand()
 				break;
 		}
 	}
-	
+
 	return str_command;
 }
 
@@ -219,19 +262,23 @@ cSection_Burst::createCommand()
 void 
 cSection_Burst::init()
 {
+/*
 	vPageNumbers = 0;
 	vDigits_Oct  = 0;
 	vDigits_Dec  = 0;
 	vDigits_Hex  = 0;
+*/
+	mFCButton_SourceFile.clear();
+	mFCDialog_SelectFolder.clear();
 
-	mFCButton_SourceFile.unselect_all();
 	mEntry_Prefix.set_text( sPrefix );
 	mEntry_Suffix.set_text( sSuffix );
+	mExpander_Extended.set_expanded( false );
 	mRButton_Auto.set_active( true );
 	rAdjust_Digits->set_value( 0.0 );
 	mSButton_Digits.set_sensitive( false );
 	mCBox_CountingBase.set_active( 1 );
-	mSwitch_Extension.set_active( true );
+	mCButton_Extension.set_active( true );
 	
 	return;
 }
